[−][src]Function arrayfire::cholesky

pub fn cholesky<T>(input: &Array<T>, is_upper: bool) -> (Array<T>, i32) where
    T: HasAfEnum + FloatingPoint, 

Perform Cholesky decomposition

Parameters

Return Values

A tuple of an Array and signed 32-bit integer.

The Array contains the triangular matrix (multiply it with conjugate transpose to reproduce the input).

If the integer is 0, it means the cholesky decomposition passed. Otherwise, it will contain the rank at which the decomposition failed.